@@ -2,7 +2,7 @@ context("grid_canopy")
 
 test_that("grid_canopy with p2r() returns a georeferenced RasterLayer", {
 
-  las <- lidR:::dummy_las(2000)
+  las <- lidR:::generate_las(2000)
   x   <- grid_canopy(las, 4, p2r())
 
   expect_true(is(x, "RasterLayer"))
@@ -48,7 +48,7 @@ test_that("grid_canopy with p2r() works with subcircle option", {
 
 test_that("grid_canopy with p2r() works with na.fill", {
 
-  las <- lidR:::dummy_las(1000)
+  las <- lidR:::generate_las(1000)
   x   <- grid_canopy(las, 4, p2r())
 
   expect_equal(sum(is.na(x[])), 118L)
@@ -58,12 +58,11 @@ test_that("grid_canopy with p2r() works with na.fill", {
   expect_equal(sum(is.na(x[])), 0L)
 })
 
-LASfile <- system.file("extdata", "MixedConifer.laz", package = "lidR")
-las <- readLAS(LASfile, select = "xyzr", filter = "-thin_with_grid 1")
-ctg <- catalog(LASfile)
+las <- readLAS(mixedconifer_las_path, select = "xyzr", filter = "-thin_with_grid 1")
+ctg <- mixedconifer_ctg
 
 opt_filter(ctg)          <- "-thin_with_grid 1"
-opt_chunk_size(ctg)      <- 50
+opt_chunk_size(ctg)      <- 100
 opt_chunk_alignment(ctg) <- c(5,15)
 opt_chunk_buffer(ctg)    <- 10
 opt_progress(ctg)        <- FALSE
@@ -104,8 +103,7 @@ test_that("grid_canopy pit-free works both with LAS and LAScatalog", {
 
 test_that("triangulation does not return negative values", {
   # See https://gis.stackexchange.com/questions/376261/negative-values-after-chm-rasterization-lidr
-  LASfile <- system.file("extdata", "Megaplot.laz", package = "lidR")
-  las <- readLAS(LASfile, select = "xyzr", filter = "-inside 684750 5017800 684850 5017900")
+  las <- clip_rectangle(megaplot, 684750, 5017800, 684850, 5017900)
   chm = grid_canopy(las, 1, dsmtin())
   expect_equal(min(chm[], na.rm = T), 0)
 })
